Startseite: BDEW Forum Datenformate
Description: Willkommen im Forum Datenformate Das Forum ist die Informations- und Kommunikationsplattform rund um die Datenformate EDI@Energy. Die Bundesnetzagentur gibt in ihren Festlegungsverfahren die einheitlichen Marktprozesse und Datenformate für die Energiewirtschaft vor. EDI@Energy ist die verbändeübergreifende Expertengruppe unter Federführung des BDEW, die die Datenformate für die Marktprozesse entwickelt. Die Dokumente zu den Marktprozessen finden Sie auf der BDEW-Homepage.
Keywords: edi,energy,bdew,forum,datenformate

Skip to main content

# Willkommen im Forum Datenformate

Das Forum ist die Informations- und Kommunikationsplattform rund um die Datenformate EDI@Energy.

Die Bundesnetzagentur gibt in ihren Festlegungsverfahren die einheitlichen Marktprozesse und Datenformate für die Energiewirtschaft vor. EDI@Energy ist die verbändeübergreifende Expertengruppe unter Federführung des BDEW, die die Datenformate für die Marktprozesse entwickelt. Die Dokumente zu den Marktprozessen finden Sie auf der BDEW-Homepage.

Dieses Forum bietet Ihnen drei Anwendungen:

- Dokumente: Es stehen Ihnen hier alle EDI@Energy-Dokumente zur Verfügung. Sie können sie nach verschiedenen Kriterien filtern und sich anzeigen lassen. Die Übersicht der EDI@Energy-Dokumente finden Sie hier.
- Diskussion: Sie haben die Möglichkeit, Fachfragen an die EDI@Energy-ExpertInnen einzustellen. Beantwortete Fragen sind für alle Nutzer sichtbar. Um Fragen einreichen zu können, können Sie sich hier registrieren.
- Newsletter: Schließlich können Sie sich zu themenbezogenen Newslettern anmelden. Auf diesem Wege werden Sie automatisch darüber informiert, wenn eine Frage beantwortet oder ein neues Dokument eingestellt wurde. Das Anmeldeformular für Newsletter finden Sie hier.

Dieses Forum lebt von seinen Nutzern. Wir laden Sie daher herzlich ein, die Marktkommunikation mit Ihren Fragen mitzugestalten.

Ihr BDEW Forum Datenformate